@@ -1,10 +1,11 @@
 package Math::Vector::Real;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 use strict;
 use warnings;
 use Carp;
+use POSIX ();
 
 use Exporter qw(import);
 our @EXPORT = qw(V);
@@ -39,6 +40,11 @@ sub new {
     bless [@_], $class
 }
 
+sub new_ref {
+    my $class = shift;
+    bless [@{shift()}], $class;
+}
+
 sub zero {
     my ($class, $dim) = @_;
     $dim >= 0 or croak "negative dimension";
@@ -274,7 +280,7 @@ sub wrap {
 
     bless [map  { my $s = $self->[$_];
 		  my $c = $v->[$_];
-		  $c - $s * floor($c/$s) } (0..$#$self)];
+		  $c - $s * POSIX::floor($c/$s) } (0..$#$self)];
 }
 
 sub max {
